@@ -253,58 +253,58 @@ sub getRpmInfo()
    
    LINE:foreach $line (@output)
    {
-       if ($line =~ /(Name+).*: ([(\/\w].*.[\w\/)]) .*. (Relocations+).*: ([(\/\w].*.[\w\/)])/)
+       if ($line =~ /(Name+).*: ([(\/\w].*.[\w\/)]) .*. (Relocations+).*: ([(\/\w].*.[\w\/)])/i)
        {
 	  $$ref{'name'} = $2;
           $$ref{'relocations'} =$4; 
           next LINE;
        }
-       if ($line =~ /(Version+).*: ([(\/\w].*.[\w\/)]) .*. (Vendor+).*: ([(\/\w].*.[\w\/)])/)
+       if ($line =~ /(Version+).*: ([(\/\w].*.[\w\/)]) .*. (Vendor+).*: ([(\/\w].*.[\w\/)])/i)
        {
           $$ref{'version'} = $2;
           $$ref{'vendor'} =$4; 
           next LINE;
        }
-       if ($line =~ /(Release+).*: ([(\/\w].*.[\w\/)]) .*. (Build Date+).*: ([(\/\w].*.[\w\/)])/)
+       if ($line =~ /(Release+).*: ([(\/\w].*.[\w\/)]) .*. (Build Date+).*: ([(\/\w].*.[\w\/)])/i)
        {
           $$ref{'release'} = $2;
           $$ref{'build_date'} =$4;     
           next LINE;
        }
-       if ($line =~ /(Install date+).*: ([(\/\w].*.[\w\/)]) .*. (Build Host+).*: ([(\/\w].*.[\w\/)])/)
+       if ($line =~ /(Install date+).*: ([(\/\w].*.[\w\/)]) .*. (Build Host+).*: ([(\/\w].*.[\w\/)])/i)
        {
           $$ref{'install_date'} = $2;
           $$ref{'build_host'} =$4;     
           next LINE;
        }
-       if ($line =~ /(Group+).*: ([(\/\w].*.[\w\/)]) .*. (Source RPM+).*: ([(\/\w].*.[\w\/)])/)
+       if ($line =~ /(Group+).*: ([(\/\w].*.[\w\/)]) .*. (Source RPM+).*: ([(\/\w].*.[\w\/)])/i)
        {
           $$ref{'group'} = $2;
           $$ref{'source_rpm'} =$4;
   	  next LINE;
        }
-       if ($line =~ /(Size+).*: ([(\/\w].*.[\w\/)]) .*. (License+).*: ([(\/\w].*.[\w\/)])/)
+       if ($line =~ /(Size+).*: ([(\/\w].*.[\w\/)]) .*. (License+).*: ([(\/\w].*.[\w\/)])/i)
        {
           $$ref{'size'} = $2;
           $$ref{'license'} =$4;
 	  next LINE;
        }
-       if ($line =~ m/(Summary+).*: ([(\/\w].*.[\w\/)])/)
+       if ($line =~ m/(Summary+).*: ([(\/\w].*.[\w\/)])/i)
        {
           $$ref{'summary'} = $2;
           next LINE;
        }
-       if ($line =~ m/(URL+).*: ([(\/\w].*.[\w\/)])/)
+       if ($line =~ m/(URL+).*: ([(\/\w].*.[\w\/)])/i)
        {
           $$ref{'url'} = $2;
           next LINE;
        }
-       if ($line =~ m/(Packager+).*: ([(\/\w].*.[\w\/)])/)
+       if ($line =~ m/(Packager+).*: ([(\/\w].*.[\w\/)])/i)
        {
           $$ref{'packager'} = $2;
           next LINE;
        }
-       if ($line =~ m/(Distribution+).*: ([(\/\w].*.[\w\/)])/)
+       if ($line =~ m/(Distribution+).*: ([(\/\w].*.[\w\/)])/i)
        {
           $$ref{'distribution'} = $2;
           next LINE;
